@@ -1,5 +1,5 @@
 package Apache::AuthCookie;
-$Apache::AuthCookie::VERSION = '3.21';
+$Apache::AuthCookie::VERSION = '3.23';
 # ABSTRACT: Perl Authentication and Authorization via cookies
 
 use strict;
@@ -166,7 +166,7 @@ sub login ($$) {
     unless ($ses_key) {
         $r->log_error("Bad credentials") if $debug >= 2;
         $r->subprocess_env('AuthCookieReason', 'bad_credentials');
-        $r->uri($params->param('destination'));
+        $r->uri($self->untaint_destination($params->param('destination')));
         return $auth_type->login_form;
     }
 
@@ -549,7 +549,7 @@ Apache::AuthCookie - Perl Authentication and Authorization via cookies
 
 =head1 VERSION
 
-version 3.21
+version 3.23
 
 =head1 SYNOPSIS
 
