@@ -1,11 +1,11 @@
 package Apache::AuthCookie::Params;
-$Apache::AuthCookie::Params::VERSION = '3.22';
+$Apache::AuthCookie::Params::VERSION = '3.23';
 # ABSTRACT: AuthCookie Params Driver for mod_perl 1.x
 
 use strict;
 use warnings;
 use base 'Apache::AuthCookie::Params::Base';
-use Class::Load qw(try_load_class load_class);
+use Class::Load qw(try_load_class);
 
 sub _new_instance {
     my ($class, $r) = @_;
@@ -20,14 +20,13 @@ sub _new_instance {
         return Apache::Request->new($r);
     }
     else {
-        load_class('CGI');
-
         $r->server->log_error("params: using CGI") if $debug >= 3;
 
         # CGI->new($r) doesn't work for POST->GET conversion in MP1, so get
         # query string manually
         my $qstring = $r->method eq 'POST' ? scalar $r->content : scalar $r->args;
-        return CGI->new($qstring);
+
+        return $class->_cgi_new($qstring);
     }
 
     return;
@@ -45,7 +44,7 @@ Apache::AuthCookie::Params - AuthCookie Params Driver for mod_perl 1.x
 
 =head1 VERSION
 
-version 3.22
+version 3.23
 
 =head1 SYNOPSIS
 
